Module font_config

Module font_config 

Font configuration and system font discovery

Provides a mapping from font family names to TTF/OTF file paths, and utilities to discover fonts installed on the system.

Structs

FontConfig
Maps font family names to font file paths.

Functions

extract_font_family_name
Extract the preferred font family name from TTF/OTF data.