Module simple

Module simple 

Simple programmatic PDF document builder.

Provides a high-level builder for generating text-only A4 PDF documents without requiring an area tree or XSL-FO pipeline. Suitable for audit logs, verification reports, and other programmatically-generated documents.

Structs

SimpleDocumentBuilder
High-level builder for simple text-only A4 PDF documents.

Enums

BuiltinFont
The 14 standard PDF Type1 builtin fonts.