Plain text rendering backend
Generates plain text output from area trees for accessibility and text extraction.
Structs
- Text
Renderer - Text renderer - converts area trees to plain text
Plain text rendering backend
Generates plain text output from area trees for accessibility and text extraction.