Font configuration and system font discovery
Provides a mapping from font family names to TTF/OTF file paths, and utilities to discover fonts installed on the system.
Structs
- Font
Config - Maps font family names to font file paths.
Functions
- extract_
font_ family_ name - Extract the preferred font family name from TTF/OTF data.